@@ -1,6 +1,6 @@
 `poLCA.postClass.C` <-
 function(prior,vp,y) {
-    res <- .C("postclass",
+    ret <-  .C("postclass",
                 as.double(t(prior)),
                 as.double(vp$vecprobs),
                 as.integer(t(y)),
@@ -10,7 +10,7 @@ function(prior,vp,y) {
                 as.integer(vp$classes),
                 posterior = double(dim(y)[1]*vp$classes)
             )
-    res$posterior <- matrix(res$posterior,ncol=vp$classes,byrow=TRUE)
-    return(res$posterior)
+    ret$posterior <- matrix(ret$posterior,ncol=vp$classes,byrow=TRUE)
+    return(ret$posterior)
 }
 
