@@ -1,6 +1,6 @@
 `poLCA.probHat.C` <-
 function(rgivy,y,vp) {
-    res <- .C("probhat",
+    ret <-  .C("probhat",
                 as.integer(t(y)),
                 as.double(t(rgivy)),
                 as.integer(length(vp$numChoices)),
@@ -9,6 +9,6 @@ function(rgivy,y,vp) {
                 as.integer(vp$classes),
                 ph = double(sum(vp$numChoices)*vp$classes)
             )
-    return(res$ph)
+    return(ret$ph)
 }
 
